# 💭 prompted | (*formerly `chatspec`)

A tiny & rapid prototyping library for working with the *OpenAI Chat Completions*,
*Google A2A* & *Anthropic Model Context Protocol* protocols.

> This library was built for my own personal use, but provides an interface that is incredibly simple to master & understand.

`chatspec`'s base implementation is meant to provide *non-client* utilities and types for these
various protocols, both for common utilities as well as helpers for implementations of patterns
found commonly within LLM & agent based applications. Optionally, you can install the
`chatspec[create]` package to install a very flexible & easy to user interface built from
`litellm` & `instructor`.

